@@ -1,6 +1,6 @@
 package Data::Format::Pretty::Console;
 BEGIN {
-  $Data::Format::Pretty::Console::VERSION = '0.09';
+  $Data::Format::Pretty::Console::VERSION = '0.10';
 }
 # ABSTRACT: Pretty-print data structure for console output
 
@@ -14,6 +14,7 @@ use Scalar::Util qw(blessed);
 use Text::ASCIITable;
 use YAML::Any;
 
+require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
@@ -190,6 +191,7 @@ sub _format_list {
         for my $i (0..@$data-1) {
             $t->addRow($self->_format_cell($data->[$i]));
         }
+        $t->setOptions({hide_HeadRow=>1, hide_HeadLine=>1});
         return $self->_render_table($t);
     } else {
         my @rows;
@@ -209,6 +211,7 @@ sub _format_hash {
         for my $k (sort keys %$data) {
             $t->addRow($k, $self->_format_cell($data->{$k}));
         }
+        $t->setOptions({hide_HeadRow=>1, hide_HeadLine=>1});
         return $self->_render_table($t);
     } else {
         my @t;
@@ -229,6 +232,7 @@ sub _format_aoa {
             for my $i (0..@$data-1) {
                 $t->addRow(map {$self->_format_cell($_)} @{ $data->[$i] });
             }
+            $t->setOptions({hide_HeadRow=>1, hide_HeadLine=>1});
             return $self->_render_table($t);
         } else {
             return "";
@@ -362,7 +366,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -380,8 +384,6 @@ Scalar, format_pretty("foo"):
 
 List, format_pretty([qw/foo bar baz qux/]):
 
- .------.
- | data |
  +------+
  | foo  |
  | bar  |
@@ -399,8 +401,6 @@ false):
 
 Hash, format_pretty({foo=>"data",bar=>"format",baz=>"pretty",qux=>"console"}):
 
- .---------------.
- | key | value   |
  +-----+---------+
  | bar | format  |
  | baz | pretty  |
@@ -411,8 +411,6 @@ Hash, format_pretty({foo=>"data",bar=>"format",baz=>"pretty",qux=>"console"}):
 2-dimensional array, format_pretty([ [1, 2, ""], [28, "bar", 3], ["foo", 3,
 undef] ]):
 
- .-----------------------------.
- | column0 | column1 | column2 |
  +---------+---------+---------+
  |       1 |       2 |         |
  |      28 | bar     |       3 |
